pub type EventId = u64;Expand description
Unique identifier of an event inside a wheel instance.
IDs are assigned by HashedWheelTimer::schedule
and preserved by update/reschedule operations.
pub type EventId = u64;Unique identifier of an event inside a wheel instance.
IDs are assigned by HashedWheelTimer::schedule
and preserved by update/reschedule operations.